@@ -1,15 +1,38 @@
 /*
- * Copyright (C) 1996-2017 The Squid Software Foundation and contributors
+ * AUTHOR: Duane Wessels
+ *
+ * SQUID Web Proxy Cache          http://www.squid-cache.org/
+ * ----------------------------------------------------------
+ *
+ *  Squid is the result of efforts by numerous individuals from
+ *  the Internet community; see the CONTRIBUTORS file for full
+ *  details.   Many organizations have provided support for Squid's
+ *  development; see the SPONSORS file for full details.  Squid is
+ *  Copyrighted (C) 2001 by the Regents of the University of
+ *  California; see the COPYRIGHT file for full details.  Squid
+ *  incorporates software developed and/or copyrighted by other
+ *  sources; see the CREDITS file for full details.
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
  *
- * Squid software is distributed under GPLv2+ license and includes
- * contributions from numerous individuals and organizations.
- * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
 #ifndef SQUID_CONFIG_H
 #define SQUID_CONFIG_H
 
-#include "autoconf.h"       /* For GNU autoconf variables */
+#include "autoconf.h"		/* For GNU autoconf variables */
 
 #if !defined(HAVE_SQUID)
 /* sub-packages define their own version details */
@@ -44,7 +67,7 @@
 
 #ifdef USE_POSIX_REGEX
 #ifndef USE_RE_SYNTAX
-#define USE_RE_SYNTAX   REG_EXTENDED    /* default Syntax */
+#define USE_RE_SYNTAX	REG_EXTENDED	/* default Syntax */
 #endif
 #endif
 
@@ -80,7 +103,11 @@
 /*
  * Determine if this is a leak check build or standard
  */
-#if PURIFY || WITH_VALGRIND
+#if PURIFY
+#define LEAK_CHECK_MODE 1
+#elif WITH_VALGRIND
+#define LEAK_CHECK_MODE 1
+#elif XMALLOC_TRACE
 #define LEAK_CHECK_MODE 1
 #endif
 
@@ -98,4 +125,3 @@ using namespace Squid;
 #include "leakcheck.h"
 
 #endif /* SQUID_CONFIG_H */
-
