@@ -1,14 +1,10 @@
-/*
- * Copyright (C) 1996-2017 The Squid Software Foundation and contributors
- *
- * Squid software is distributed under GPLv2+ license and includes
- * contributions from numerous individuals and organizations.
- * Please see the COPYING and CONTRIBUTORS files for details.
- */
-
 #ifndef SQUID_DNS_H
 #define SQUID_DNS_H
 
+#if USE_DNSHELPER
+#include "helper.h"
+#endif
+
 namespace Ip
 {
 class Address;
@@ -18,9 +14,13 @@ class Address;
 void dnsInit(void);
 void dnsShutdown(void);
 
+#if USE_DNSHELPER
+// external DNS helper API
+void dnsSubmit(const char *lookup, HLPCB * callback, void *data);
+#else
 // internal DNS client API
 void idnsALookup(const char *, IDNSCB *, void *);
 void idnsPTRLookup(const Ip::Address &, IDNSCB *, void *);
+#endif
 
 #endif /* SQUID_DNS_H */
-
