@@ -1,11 +1,3 @@
-/*
- * Copyright (C) 1996-2016 The Squid Software Foundation and contributors
- *
- * Squid software is distributed under GPLv2+ license and includes
- * contributions from numerous individuals and organizations.
- * Please see the COPYING and CONTRIBUTORS files for details.
- */
-
 #ifndef SQUID_BASE_INSTANCE_ID_H
 #define SQUID_BASE_INSTANCE_ID_H
 
@@ -25,41 +17,35 @@ class InstanceId
 public:
     typedef unsigned int Value; ///< id storage type; \todo: parameterize?
 
-    InstanceId(): value(0) {change();}
+    InstanceId(): value(++Last ? Last : ++Last) {}
 
     operator Value() const { return value; }
     bool operator ==(const InstanceId &o) const { return value == o.value; }
     bool operator !=(const InstanceId &o) const { return !(*this == o); }
-    void change();
+    void change() {value = ++Last ? Last : ++Last;}
 
-    /// prints class-pecific prefix followed by ID value; \todo: use HEX for value printing?
+    /// prints Prefix followed by ID value; \todo: use HEX for value printing?
     std::ostream &print(std::ostream &os) const;
 
-    /// returns the class-pecific prefix
-    const char * const prefix() const;
-
 public:
+    static const char *Prefix; ///< Class shorthand string for debugging
     Value value; ///< instance identifier
 
 private:
     InstanceId(const InstanceId& right); ///< not implemented; IDs are unique
     InstanceId& operator=(const InstanceId &right); ///< not implemented
+
+private:
+    static Value Last; ///< the last used ID value
 };
 
 /// convenience macro to instantiate Class-specific stuff in .cc files
-#define InstanceIdDefinitions(Class, pfx) \
-    template<> const char * const \
-    InstanceId<Class>::prefix() const { \
-        return pfx; \
-    } \
+#define InstanceIdDefinitions(Class, prefix) \
+    template<> const char *InstanceId<Class>::Prefix = prefix; \
+    template<> InstanceId<Class>::Value InstanceId<Class>::Last = 0; \
     template<> std::ostream & \
     InstanceId<Class>::print(std::ostream &os) const { \
-        return os << pfx << value; \
-    } \
-    template<> void \
-    InstanceId<Class>::change() { \
-        static InstanceId<Class>::Value Last = 0; \
-        value = ++Last ? Last : ++Last; \
+        return os << Prefix << value; \
     }
 
 /// print the id
@@ -71,4 +57,3 @@ std::ostream &operator <<(std::ostream &os, const InstanceId<Class> &id)
 }
 
 #endif /* SQUID_BASE_INSTANCE_ID_H */
-
